@@ -205,7 +205,7 @@ class API(metaclass=Singleton):
             current_page += 1
             status, response = self.__get_user_segments_mapping_page(
                 fields=fields,
-                token=token
+                token=token,
                 page=current_page,
                 limit=10000,
             )
@@ -273,8 +273,6 @@ class API(metaclass=Singleton):
         }
         response = session.put(path, json=body, headers=headers)
         return response
-
-
     # Tasks:    
 
     def update_task(self, status, task_id, count_response, error=None):
