@@ -43,9 +43,10 @@ class ApiResponseError(Exception):
             name -- error name
             status_code -- http response error code
     """
-    def __init__(self, name, status_code):
+    def __init__(self, name, status_code, data = None):
         self.name = name
         self.status_code = status_code
+        self.data = data
 
 
 class SaveFileError(Exception):
